@@ -191,6 +191,13 @@ def plot_2D_Data(
     # Find main axis as the axis with the most values
     # main_axis = axes_list[0]  # max(axes_list, key=lambda x: x.values.size)
 
+    # Remove axis that has been factorized from axis list
+    # [
+    #     axes_list.pop(i)
+    #     for i in range(len(axes_list))
+    #     if axes_list[i].extension in ["sum", "rss", "mean", "rms", "integrate"]
+    # ]
+
     # Build xlabel and title parts 2 and 3
     title2 = ""
     title3 = " for "
@@ -216,7 +223,10 @@ def plot_2D_Data(
         ):
             title2 = "over " + name.lower()
             if axis.unit == "SI":
-                unit = unit_dict[axis.name]
+                if axis.name in unit_dict:
+                    unit = unit_dict[axis.name]
+                else:
+                    unit = axis.unit
                 xlabel = name.capitalize() + " [" + unit + "]"
                 main_axis_name = name
             elif axis.unit in norm_dict:
@@ -239,19 +249,25 @@ def plot_2D_Data(
                 xticks = None
         else:
             if axis.unit == "SI":
-                unit = unit_dict[axis.name]
+                if axis.name in unit_dict:
+                    unit = unit_dict[axis.name]
+                else:
+                    unit = axis.unit
             elif axis.unit in norm_dict:
                 unit = norm_dict[axis.unit]
             else:
                 unit = axis.unit
 
-            axis_str = array2string(
-                result_0[axis.name], formatter={"float_kind": "{:.3g}".format}
-            ).replace(" ", ", ")
-            if len(result_0[axis.name]) == 1:
-                axis_str = axis_str.strip("[]")
+            if isinstance(result_0[axis.name], str):
+                title3 += name + "=" + result_0[axis.name]
+            else:
+                axis_str = array2string(
+                    result_0[axis.name], formatter={"float_kind": "{:.3g}".format}
+                ).replace(" ", ", ")
+                if len(result_0[axis.name]) == 1:
+                    axis_str = axis_str.strip("[]")
 
-            title3 += name + "=" + axis_str.rstrip(", ") + " [" + unit + "], "
+                title3 += name + "=" + axis_str.rstrip(", ") + " [" + unit + "], "
 
     # Title part 4 containing axes that are here but not involved in requested axes
     title4 = ""
@@ -304,7 +320,10 @@ def plot_2D_Data(
                         linestyles = ["dashed"]
                 n_curves = len(axis.values)
                 if axis.unit == "SI":
-                    unit = unit_dict[axis.name]
+                    if axis.name in unit_dict:
+                        unit = unit_dict[axis.name]
+                    else:
+                        unit = axis.unit
                 elif axis.unit in norm_dict:
                     unit = norm_dict[axis.unit]
                 else:
@@ -364,7 +383,7 @@ def plot_2D_Data(
             for ind, y in enumerate(Ydatas[0])
             if abs(y) > abs(thresh * np_max(Ydatas[0]))
         ]
-        xticks = unique(insert(0, 0, freqs[indices]))
+        xticks = unique(insert(freqs[indices], 0, 0))
 
         if is_auto_range:
             if len(xticks) > 0:
@@ -465,4 +484,5 @@ def plot_2D_Data(
             font_size_title=font_size_title,
             font_size_label=font_size_label,
             font_size_legend=font_size_legend,
+            is_show_legend=True,
         )
